Crate pg_lease

Crate pg_lease 

Structs

LeaseContext
LeaseLooper
A lease-based looper that ensures only one worker can execute a task at a time across multiple processes/machines using PostgreSQL as the coordination mechanism.
LeaseLooperOptions

Functions

force_revoke_lease
Force revokes a lease by deleting it from the database regardless of who holds it.
verify_lease_held
Transactionally verifies that a lease is held by the specified worker.