Structs
- Lease
Context - Lease
Looper - A lease-based looper that ensures only one worker can execute a task at a time across multiple processes/machines using PostgreSQL as the coordination mechanism.
- Lease
Looper Options
Functions
- force_
revoke_ lease - Force revokes a lease by deleting it from the database regardless of who holds it.
- verify_
lease_ held - Transactionally verifies that a lease is held by the specified worker.